@@ -1,6 +1,5 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-
 """Types and structures to support error-handling as specified by XCP.
 """
 
@@ -104,10 +103,19 @@ ERROR_TABLE = {
     XcpError.ERR_CMD_BUSY: ("Command was not executed.", Severity.S2),
     XcpError.ERR_DAQ_ACTIVE: ("Command rejected because DAQ is running.", Severity.S2),
     XcpError.ERR_PGM_ACTIVE: ("Command rejected because PGM is running.", Severity.S2),
-    XcpError.ERR_CMD_UNKNOWN: ("Unknown command or not implemented optional command.", Severity.S2),
+    XcpError.ERR_CMD_UNKNOWN: (
+        "Unknown command or not implemented optional command.",
+        Severity.S2,
+    ),
     XcpError.ERR_CMD_SYNTAX: ("Command syntax invalid", Severity.S2),
-    XcpError.ERR_OUT_OF_RANGE: ("Command syntax valid but command parameter(s) out of range.", Severity.S2),
-    XcpError.ERR_WRITE_PROTECTED: ("The memory location is write protected.", Severity.S2),
+    XcpError.ERR_OUT_OF_RANGE: (
+        "Command syntax valid but command parameter(s) out of range.",
+        Severity.S2,
+    ),
+    XcpError.ERR_WRITE_PROTECTED: (
+        "The memory location is write protected.",
+        Severity.S2,
+    ),
     XcpError.ERR_ACCESS_DENIED: ("The memory location is not accessible.", Severity.S2),
     XcpError.ERR_ACCESS_LOCKED: ("Access denied, Seed & Key is required", Severity.S2),
     XcpError.ERR_PAGE_NOT_VALID: ("Selected page not available", Severity.S2),
@@ -117,7 +125,10 @@ ERROR_TABLE = {
     XcpError.ERR_DAQ_CONFIG: ("DAQ configuration not valid", Severity.S2),
     XcpError.ERR_MEMORY_OVERFLOW: ("Memory overflow error", Severity.S2),
     XcpError.ERR_GENERIC: ("Generic error.", Severity.S2),
-    XcpError.ERR_VERIFY: ("The slave internal program verify routine detects an error.", Severity.S3),
+    XcpError.ERR_VERIFY: (
+        "The slave internal program verify routine detects an error.",
+        Severity.S3,
+    ),
     XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
         "Access to the requested resource is temporary not possible",
         Severity.S2,
@@ -128,7 +139,10 @@ ERROR_TABLE = {
 ERROR_MATRIX = {
     Command.CONNECT: {
         XcpError.ERR_TIMEOUT: ((PreAction.NONE,), Action.REPEAT_INF_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     # CONNECT(USER_DEFINED)  timeout t6  wait t7  repeat  8 times
     Command.DISCONNECT: {
@@ -138,13 +152,19 @@ ERROR_MATRIX = {
     },
     Command.GET_STATUS: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SYNCH: {
         XcpError.ERR_TIMEOUT: ((PreAction.NONE,), Action.REPEAT_2_TIMES),
         XcpError.ERR_CMD_SYNCH: ((PreAction.NONE), Action.SKIP),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.RESTART_SESSION),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_COMM_MODE_INFO: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -157,6 +177,7 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
+        XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.NONE, Action.SKIP),
     },
     Command.SET_REQUEST: {
@@ -166,7 +187,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_SEED: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -175,7 +199,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.UNLOCK: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -186,7 +213,10 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.NONE), Action.RESTART_SESSION),
         XcpError.ERR_SEQUENCE: ((PreAction.GET_SEED_UNLOCK), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SET_MTA: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -195,10 +225,16 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.UPLOAD: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
@@ -206,7 +242,10 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SHORT_UPLOAD: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -217,10 +256,16 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.BUILD_CHECKSUM: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
@@ -228,7 +273,10 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.TRANSPORT_LAYER_CMD: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -236,7 +284,10 @@ ERROR_MATRIX = {
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.USER_CMD: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -244,10 +295,16 @@ ERROR_MATRIX = {
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.DOWNLOAD: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
@@ -256,10 +313,16 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.DOWNLOAD_NEXT: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.DOWNLOAD), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.DOWNLOAD),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.SET_MTA), Action.USE_ALTERATIVE),
@@ -270,10 +333,16 @@ ERROR_MATRIX = {
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_SEQUENCE: ((PreAction.SET_MTA), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.DOWNLOAD_MAX: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.SET_MTA), Action.USE_ALTERATIVE),
@@ -283,7 +352,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SHORT_DOWNLOAD: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -296,20 +368,32 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.MODIFY_BITS: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
-        XcpError.ERR_CMD_UNKNOWN: ((PreAction.UPLOAD, PreAction.DOWNLOAD), Action.USE_ALTERATIVE),
+        XcpError.ERR_CMD_UNKNOWN: (
+            (PreAction.UPLOAD, PreAction.DOWNLOAD),
+            Action.USE_ALTERATIVE,
+        ),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SET_CAL_PAGE: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -320,7 +404,10 @@ ERROR_MATRIX = {
         XcpError.ERR_PAGE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_SEGMENT_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_CAL_PAGE: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -331,7 +418,10 @@ ERROR_MATRIX = {
         XcpError.ERR_PAGE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_SEGMENT_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_PAG_PROCESSOR_INFO: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -373,7 +463,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_SEGMENT_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_SEGMENT_MODE: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -383,7 +476,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEGMENT_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.COPY_CAL_PAGE: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -394,7 +490,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_PAGE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_SEGMENT_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SET_DAQ_PTR: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -404,10 +503,16 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.WRITE_DAQ: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_DAQ_PTR), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_DAQ_PTR),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_DAQ_ACTIVE: ((PreAction.START_STOP_X), Action.REPEAT_2_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
@@ -417,7 +522,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_DAQ_CONFIG: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.SET_DAQ_LIST_MODE: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -428,7 +536,10 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.START_STOP_DAQ_LIST: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -439,7 +550,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_DAQ_CONFIG: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.START_STOP_SYNCH: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -449,7 +563,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MODE_NOT_VALID: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_DAQ_CONFIG: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.CLEAR_DAQ_LIST: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -459,7 +576,10 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_DAQ_LIST_INFO: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -472,7 +592,10 @@ ERROR_MATRIX = {
         XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.NONE, Action.SKIP),
     },
     Command.WRITE_DAQ_MULTIPLE: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_DAQ_PTR), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_DAQ_PTR),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_DAQ_ACTIVE: ((PreAction.START_STOP_X), Action.REPEAT_2_TIMES),
@@ -483,16 +606,25 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_WRITE_PROTECTED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_DAQ_CONFIG: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.READ_DAQ: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_DAQ_PTR), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_DAQ_PTR),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_PGM_ACTIVE: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_DAQ_CLOCK: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -528,7 +660,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_DAQ_EVENT_INFO: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -547,7 +682,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.ALLOC_DAQ: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -559,7 +697,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.REINIT_DAQ), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.REINIT_DAQ), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.ALLOC_ODT: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -571,7 +712,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.REINIT_DAQ), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.REINIT_DAQ), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.ALLOC_ODT_ENTRY: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -583,7 +727,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.REINIT_DAQ), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.REINIT_DAQ), Action.RETRY_PARAM),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_START: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -592,20 +739,32 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_GENERIC: ((PreAction.NONE), Action.RESTART_SESSION),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_CLEAR: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_DENIED: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
@@ -613,7 +772,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_RESET: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -622,7 +784,10 @@ ERROR_MATRIX = {
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.GET_PGM_PROCESSOR_INFO: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -643,7 +808,10 @@ ERROR_MATRIX = {
         XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.NONE, Action.SKIP),
     },
     Command.PROGRAM_PREPARE: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
@@ -651,7 +819,10 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
         XcpError.ERR_GENERIC: ((PreAction.NONE), Action.RESTART_SESSION),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_FORMAT: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -661,10 +832,16 @@ ERROR_MATRIX = {
         XcpError.ERR_OUT_OF_RANGE: ((PreAction.NONE), Action.RETRY_PARAM),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_NEXT: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.PROGRAM), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.PROGRAM),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.USE_ALTERATIVE),
         XcpError.ERR_CMD_SYNTAX: ((PreAction.NONE), Action.RETRY_SYNTAX),
@@ -673,16 +850,25 @@ ERROR_MATRIX = {
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_MAX: {
-        XcpError.ERR_TIMEOUT: ((PreAction.SYNCH, PreAction.SET_MTA), Action.REPEAT_2_TIMES),
+        XcpError.ERR_TIMEOUT: (
+            (PreAction.SYNCH, PreAction.SET_MTA),
+            Action.REPEAT_2_TIMES,
+        ),
         XcpError.ERR_CMD_BUSY: ((PreAction.WAIT_T7), Action.REPEAT_INF_TIMES),
         XcpError.ERR_CMD_UNKNOWN: ((PreAction.NONE), Action.USE_ALTERATIVE),
         XcpError.ERR_ACCESS_LOCKED: ((PreAction.UNLOCK_SLAVE), Action.REPEAT_2_TIMES),
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
         XcpError.ERR_MEMORY_OVERFLOW: ((PreAction.NONE), Action.DISPLAY_ERROR),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
     Command.PROGRAM_VERIFY: {
         XcpError.ERR_TIMEOUT: ((PreAction.SYNCH,), Action.REPEAT_2_TIMES),
@@ -694,7 +880,10 @@ ERROR_MATRIX = {
         XcpError.ERR_SEQUENCE: ((PreAction.NONE), Action.REPEAT_2_TIMES),
         XcpError.ERR_GENERIC: ((PreAction.NONE), Action.RESTART_SESSION),
         XcpError.ERR_VERIFY: ((PreAction.NONE), Action.NEW_FLASH_WARE),
-        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (PreAction.DISPLAY_ERROR, Action.REPEAT),
+        XcpError.ERR_RESOURCE_TEMPORARY_NOT_ACCESSIBLE: (
+            PreAction.DISPLAY_ERROR,
+            Action.REPEAT,
+        ),
     },
 }
 
