@@ -1,5 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
+from collections import OrderedDict
+from pprint import pprint
 
 __copyright__ = """
     pySART - Simplified AUTOSAR-Toolkit for Python.
@@ -111,9 +113,7 @@ def timecode(ticks, mode):
 
 
 def cstest():
-    tr = transport.Eth(
-        "localhost", port=5555, protocol="UDP", loglevel="WARN"
-    )  # "DEBUG"
+    tr = transport.Eth("localhost", port=5555, protocol="UDP", loglevel="WARN")  # "DEBUG"
     # tr = transport.SxI("COM27", 115200, loglevel = "WARN")
     with Master(tr) as xm:
         #    tm = Timing()
@@ -177,7 +177,7 @@ def cstest():
 
         startMeasurement(xm)
         ##
-        ##    xm.freeDaq()
+        # xm.freeDaq()
         ##    print("AllocDAQ:", xm.allocDaq(2))
         ##
         ##    print("allocOdt", xm.allocOdt(1, 5))
@@ -226,8 +226,6 @@ def cstest():
 
 #   print(tr.timing)
 
-from collections import OrderedDict
-from pprint import pprint
 
 # import pandas as pd
 
