@@ -56,4 +56,8 @@ def test_read_toml_config():
 
 def test_read_dict():
     assert readConfiguration({"A": 1, "B": 2, "C": 3}) == {"A": 1, "B": 2, "C": 3}
-    assert readConfiguration(OrderedDict({"A": 1, "B": 2, "C": 3})) == {"A": 1, "B": 2, "C": 3}
+    assert readConfiguration(OrderedDict({"A": 1, "B": 2, "C": 3})) == {
+        "A": 1,
+        "B": 2,
+        "C": 3,
+    }
