@@ -34,7 +34,7 @@ def hexDump(arr):
         size = len(arr)
         try:
             arr = arr.hex()
-        except:
+        except BaseException:
             arr = hexlify(arr).decode("ascii")
         return "[{}]".format(" ".join([arr[i * 2 : (i + 1) * 2] for i in range(size)]))
     elif isinstance(arr, (list, tuple)):
@@ -42,7 +42,7 @@ def hexDump(arr):
         size = len(arr)
         try:
             arr = arr.hex()
-        except:
+        except BaseException:
             arr = hexlify(arr).decode("ascii")
         return "[{}]".format(" ".join([arr[i * 2 : (i + 1) * 2] for i in range(size)]))
     else:
@@ -53,10 +53,7 @@ def slicer(iterable, sliceLength, converter=None):
     if converter is None:
         converter = type(iterable)
     length = len(iterable)
-    return [
-        converter((iterable[item : item + sliceLength]))
-        for item in range(0, length, sliceLength)
-    ]
+    return [converter((iterable[item : item + sliceLength])) for item in range(0, length, sliceLength)]
 
 
 def flatten(*args):
